@@ -429,6 +429,8 @@ class KeyInspector(types.IKeyInspector):
         return self._jwk_properties(
             key=key,
             kty="OKP",
+            alg='EdDSA',
+            use='sig',
             crv="Ed448",
             x=b64encode(
                 key.public_bytes(
@@ -444,6 +446,8 @@ class KeyInspector(types.IKeyInspector):
         return self._jwk_properties(
             key=key,
             kty="OKP",
+            alg='EdDSA',
+            use='sig',
             crv="Ed448",
             x=b64encode(
                 public.public_bytes(
@@ -465,6 +469,7 @@ class KeyInspector(types.IKeyInspector):
         return self._jwk_properties(
             key=key,
             kty="OKP",
+            use='enc',
             crv="X448",
             x=b64encode(
                 key.public_bytes(
@@ -480,6 +485,7 @@ class KeyInspector(types.IKeyInspector):
         return self._jwk_properties(
             key=key,
             kty="OKP",
+            use='enc',
             crv="X448",
             x=b64encode(
                 public.public_bytes(
@@ -501,6 +507,8 @@ class KeyInspector(types.IKeyInspector):
         return self._jwk_properties(
             key=key,
             kty="OKP",
+            alg='EdDSA',
+            use='sig',
             crv="Ed25519",
             x=b64encode(
                 key.public_bytes(
@@ -516,6 +524,8 @@ class KeyInspector(types.IKeyInspector):
         return self._jwk_properties(
             key=key,
             kty="OKP",
+            alg='EdDSA',
+            use='sig',
             crv="Ed25519",
             x=b64encode(
                 public.public_bytes(
@@ -537,6 +547,7 @@ class KeyInspector(types.IKeyInspector):
         return self._jwk_properties(
             key=key,
             kty="OKP",
+            use="enc",
             crv="X25519",
             x=b64encode(
                 key.public_bytes(
@@ -552,6 +563,7 @@ class KeyInspector(types.IKeyInspector):
         return self._jwk_properties(
             key=key,
             kty="OKP",
+            use="enc",
             crv="X25519",
             x=b64encode(
                 public.public_bytes(
