@@ -23,6 +23,7 @@ from .jsonwebsignature import JSONWebSignature
 from .keyspecification import KeySpecification
 from .publickeyspecification import PublicKeySpecification
 from .remoteblobparams import RemoteBlobParams
+from .signature import Signature
 
 
 __all__ = [
@@ -37,4 +38,5 @@ __all__ = [
     'KeySpecification',
     'PublicKeySpecification',
     'RemoteBlobParams',
-]
\ No newline at end of file
+    'Signature'
+]
