@@ -79,7 +79,7 @@ class Provider(IProvider):
         self.inspector = inspector or KeyInspector()
         self.on_init()
 
-    def jwk(self, spec: KeySpecification, private: bool) -> JSONWebKey:
+    def jwk(self, spec: KeySpecification, private: bool, **claims: Any) -> JSONWebKey:
         key = spec.get_public_key() if not private else spec.get_private_key()
         ops = spec.key_ops
         if not private:
@@ -89,7 +89,8 @@ class Provider(IProvider):
             'kid': spec.kid,
             'kty': spec.kty,
             'alg': spec.algorithm,
-            'key_ops': ops
+            'key_ops': ops,
+            **claims
         })
 
     def on_init(self) -> None:
